==> certmanager-model-v1alpha2-5.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ChallengeBuilder extends io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluentImpl<io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge,io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeBuilder>{
  public ChallengeBuilder() {
    this(false);
  }
  public ChallengeBuilder(java.lang.Boolean validationEnabled) {
    this(new Challenge(), validationEnabled);
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluent<?> fluent) {
    this(fluent, false);
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Challenge(), validationEnabled);
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge instance) {
    this(fluent, instance, false);
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge instance) {
    this(instance,false);
  }
  public ChallengeBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.acme.v1alpha2.ChallengeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.acme.v1alpha2.Challenge build() {
    Challenge buildable = new Challenge(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChallengeBuilder that = (ChallengeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ChallengeBuilder extends ChallengeFluentImpl<ChallengeBuilder> implements VisitableBuilder<Challenge,ChallengeBuilder>{
  public ChallengeBuilder() {
    this(false);
  }
  public ChallengeBuilder(Boolean validationEnabled) {
    this(new Challenge(), validationEnabled);
  }
  public ChallengeBuilder(ChallengeFluent<?> fluent) {
    this(fluent, false);
  }
  public ChallengeBuilder(ChallengeFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Challenge(), validationEnabled);
  }
  public ChallengeBuilder(ChallengeFluent<?> fluent,Challenge instance) {
    this(fluent, instance, false);
  }
  public ChallengeBuilder(ChallengeFluent<?> fluent,Challenge instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public ChallengeBuilder(Challenge instance) {
    this(instance,false);
  }
  public ChallengeBuilder(Challenge instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  ChallengeFluent<?> fluent;
  Boolean validationEnabled;
  public Challenge build() {
    Challenge buildable = new Challenge(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
